/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include "task.h"

#ifndef ___M_SEQUENCE_H___
#define ___M_SEQUENCE_H___


#define MS_INFO_NUM 100
extern int user_interface_task_id;

#ifdef __cplusplus 
extern "C"{
#endif

typedef struct ms_info
{
	struct ms_info *	next;
	int 			(*func)();
	void * 			arg;
	char 			str[256];
	int 			result;
} MS_INFO;

void init_msequence();

void ms_loop();
void ms_loop_proc();
int ms_do(int (*func)(void *param), void * arg, char str[]);
int get_userinterface_tid();
#define WM_MSEQUENCE (WM_USER+5)

int get_v_loop_tid();
#define WM_MSEQUENCE (WM_USER+5)

int get_userinterface_tid();
#define WM_MSEQUENCE (WM_USER+5)

int get_v_loop_tid();

void ms_unlock();
int ms_lock(int wait_flag,char * file,int line);
void ms_inheritance(int,char*,int);


#ifdef __cplusplus 
}
#endif

#endif